api.reports.v1.test_helpers.search package — Argus-Toolbelt 1.0 documentation

# api.reports.v1.test_helpers.search package

## Submodules

## api.reports.v1.test_helpers.search.simplified_search_reports module

`api.reports.v1.test_helpers.search.simplified_search_reports.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/search, respond with HTTP 403

`api.reports.v1.test_helpers.search.simplified_search_reports.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/search, respond with HTTP 404

`api.reports.v1.test_helpers.search.simplified_search_reports.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/search, respond with HTTP 200

`api.reports.v1.test_helpers.search.simplified_search_reports.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reports/v1/search, respond with HTTP 401

## Module contents